@@ -1,10 +1,7 @@
 /*
 lsodes.h
 
-   written by Zeng G. Yuan
-   19 January 1993
-
-   Copyright (c) 1993-2004.  Don Maszle, Frederic Bois.  All rights reserved.
+   Copyright (c) 1993-2004.  Don Maszle, Frederic Bois.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -18,7 +15,7 @@ lsodes.h
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+   Foundation, Inc., 51 Franklin Street, 5th Floor, Boston, MA 02110-1301, USA.
 
    -- Revisions -----
      Logfile:  %F%
