@@ -3,7 +3,7 @@
    written by Frederic Bois
    5 January 1996
 
-   Copyright (c) 1996-2004.  Frederic Bois.  All rights reserved.
+   Copyright (c) 1996-2004.  Frederic Bois.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+   Foundation, Inc., 51 Franklin Street, 5th Floor, Boston, MA 02110-1301, USA.
 
    -- Revisions -----
      Logfile:  %F%
@@ -1033,6 +1033,7 @@ void ListToPVArrayL (PVOID pData, PVOID pUser1, PVOID pUser2, PVOID pUser3)
 double LnDensity (PMCVAR pMCVar, PANALYSIS panal)
 {
   double dTmp = 0, density;
+  double dTmp2, dTmp3, dTmp4;
   double dParm1 = *(pMCVar->pdParm[0]);
   double dParm2 = *(pMCVar->pdParm[1]);
   double dMin   = *(pMCVar->pdParm[2]);
@@ -1047,6 +1048,13 @@ double LnDensity (PMCVAR pMCVar, PANALYSIS panal)
       exit (0);
     }
   }
+  else if (pMCVar->iType == MCV_GENLOGNORMAL || 
+	   pMCVar->iType == MCV_STUDENTT) {
+    if (dParm1 < 0) {
+      printf ("Error: parameter %g out of bounds in LnDensity\n",dParm1);
+      exit (0);
+    }
+  }
   else {
     if (dTheta > dMax || dTheta < dMin) {
       return (NULL_SUPPORT);
@@ -1227,6 +1235,40 @@ double LnDensity (PMCVAR pMCVar, PANALYSIS panal)
         return dTmp;
       }
 
+    case MCV_GENLOGNORMAL: /* Generalized LogNormal */
+      if (dParm1 < 0) {
+        printf ("Error: bad expectation for GenLogNormal variate "
+                "in LnDensity\n");
+        exit (0);
+      }
+      /* This is relative stdev of lognormal part -- dMin is sigma for the
+	 lognormal part */
+      dTmp = sqrt(exp(pow(dMin,2)) * (exp(pow(dMin,2)) - 1)); 
+      /* This is the transformation parameter lambda */
+      dTmp2 = pow(dParm2/dTmp,2);
+      /* This is the transformed mean */
+      dTmp3 = log(dParm1 + sqrt(pow(dParm1,2) + dTmp2));
+      /* This is the transformed theta -- use Taylor series for 
+         negative dTheta when lambda/dTheta^2 < 0.01 */
+      if ((dTheta < 0) && (dTmp2 < (0.01*dTheta*dTheta)))
+	dTmp4 = log(dTmp2/(-2*dTheta)*(1+0.25*dTmp2/pow(dTheta,2)));
+      else
+	dTmp4 = log(dTheta + sqrt(pow(dTheta,2) + dTmp2));
+      /* Normal log-density minus log-jacobian */
+      return lnDFNormal( dTmp4, dTmp3, dTmp ) - 0.5*log(pow(dTmp4,2) + dTmp2);
+
+    case MCV_STUDENTT: /* Student T */
+	               /* dParm1 is dof, dParm2 is m, dMin is sigma */
+      if (dParm1 <= 0) {
+        printf ("Error: bad dof for Student-T variate"
+		"in LnDensity\n");
+        exit(0);
+      }
+      dTmp = (dParm1 + 1)/ 2;
+      return (lnGamma(dTmp) - lnGamma(dParm1 / 2)
+	      -0.5 * log(dParm1 * PI *dMin *dMin)
+	      -dTmp * log(1 + pow((dTheta - dParm2) / dMin, 2) / dParm1));
+
     default:
       ReportRunTimeError(panal, RE_UNKNOWNDIST | RE_FATAL, "LnDensity");
 
