@@ -4,7 +4,7 @@
    modifications by Don Robert Maszle
    8 January 1992
 
-   Copyright (c) 1992-2004.  Don Maszle, Frederic Bois.  All rights reserved.
+   Copyright (c) 1992-2004.  Don Maszle, Frederic Bois.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -18,7 +18,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+   Foundation, Inc., 51 Franklin Street, 5th Floor, Boston, MA 02110-1301, USA.
 
    -- Revisions -----
      Logfile:  %F%
@@ -37,41 +37,45 @@
  * Also available are several other types of random variates:
 
    BetaRandom(alpha, beta, a, b)      -- Beta(alpha, beta) over [a, b]
-   BinomialBetaRandom(E, a, b)        -- BetaBinomial (n = E + E * a / b)
+   BinomialBetaRandom(E, a, b)        -- BetaBinomial(n = E + E * a / b)
    BinomialRandom(p, n)               -- Binomial of n trials, P(each) = p
    Chi2Random(dof)                    -- Chi-squared w/dof degrees of freedom
    ExpRandom(beta)                    -- Exponential of inverse scale beta
-   InvGGammaRandom (alpha, beta)      -- General inverse gamma variate
-   GammaRandom (alpha)                -- Gamma variate
-   GGammaRandom (alpha, beta)         -- General gamma variate
-   LogNormalRandom (m, s)             -- exp (Normal)
+   InvGGammaRandom(alpha, beta)       -- General inverse gamma variate
+   GammaRandom(alpha)                 -- Gamma variate
+   GGammaRandom(alpha, beta)          -- General gamma variate
+   LogNormalRandom(m, s)              -- exp(Normal)
+   GenLogNormalRandom(m, sn, sln)     -- Generalized log transformation of the 
+                                         two-component error model
+   StudentTRandom(dof, m, s)          -- Student-t with dof degrees of freedom
+                                         location m and scale s
    LogUniformRandom(a, b)             -- LogUniform over [a, b]
    Multinomial(...)                   -- Multinomial variates
-   NormalRandom (m, s)                -- General Normal
-   PiecewiseRandom (min, a, b, max)            -- Draws from a mayan pyramid !
-   PiecewiseVariate (n, x[], p[], Cdf[], o, p) -- Draws from a tabulated PDF
+   NormalRandom(m, s)                 -- General Normal
+   PiecewiseRandom(min, a, b, max)             -- Draws from a Mayan pyramid !
+   PiecewiseVariate(n, x[], p[], Cdf[], o, p)  -- Draws from a tabulated PDF
    PoissonRandom(mu)                  -- Poisson with rate mu
-   TruncInvGGammaRandom (alpha, beta, a, b)    -- Truncated general inv-gamma
-   TruncLogNormalRandom (m, s, a, b)  -- Truncated log normal
-   TruncNormalRandom (m, s, a, b)     -- Truncated general normal
+   TruncInvGGammaRandom(alpha, beta, a, b)     -- Truncated general inv-gamma
+   TruncLogNormalRandom(m, s, a, b)   -- Truncated log normal
+   TruncNormalRandom(m, s, a, b)      -- Truncated general normal
    UniformRandom(a, b)                -- Uniform over [a, b]
-   WishartRandom(...)                 -- Wishart (matrix) variates
+   WishartRandom(...)                 -- Wishart(matrix) variates
 
  * And utility functions:
 
    CDFNormal(z)                                -- Integral of the normal at z
-   CalcCumulative (n, x[], p[], Cdf[], o)      -- Constructs a CDF given a PDF
+   CalcCumulative(n, x[], p[], Cdf[], o)       -- Constructs a CDF given a PDF
    erfc(x)                                     -- Complementary error function
    lnDFNormal(x, mu, sd)                       -- Log of the normal density
    lnGamma(x)                                  -- Natural log of gamma function
-   lnDFBeta (x, alpha, beta, min, max)         -- Log of beta density
+   lnDFBeta(x, alpha, beta, min, max)          -- Log of beta density
    SetSeed(seed)                               -- Sets the seed of Randoms
    InitRandom(seed, f)                         -- Initializes the package
 
  * The random number generator must be initialized by providing a seed
-   to InitRandom().  A non-zero second argument to this function
+   to InitRandom(). A non-zero second argument to this function
    instructs the random number generator to "warm up" by filling a
-   memory array used by RandomShuffle().  This also initializes a flag
+   memory array used by RandomShuffle(). This also initializes a flag
    used by the Normal() routine.
 
    If the random number generator is not initialized before any of its
@@ -246,7 +250,7 @@ double Randoms (void)
 /* ----------------------------------------------------------------------------
    RandomShuffle
 
-   assumes that the random number generator is Randoms ().
+   Assumes that the random number generator is Randoms ().
    RandomShuffle() shuffles the output of this generator.
 
    The routine is initialized by calling InitRandom().  A check is
@@ -313,7 +317,7 @@ double NormalRandom (double dMean, double dStdDev)
 /* ----------------------------------------------------------------------------
    LogNormalRandom
 
-   returns a variate such that the log of the variate is normally
+   Returns a variate such that the log of the variate is normally
    distributed.
 */
 
@@ -339,6 +343,77 @@ double LogNormalRandom (double dMean, double dStdDev)
 } /* LogNormalRandom */
 
 
+/* ----------------------------------------------------------------------------
+   GenLogNormalRandom
+
+   Returns a variate drawn from the generalized lognormal distribution,
+   which is an approximation of the two-component error model of Rocke 
+   and Lorenzato 1995. At low values of the mean, it is approximately 
+   normal and at high values of the mean, it is approximately lognormal
+
+   Note that here StdDevLogNorm is sigma in log space -- this convention
+   is different from that for the LogNormal.
+*/
+
+double GenLogNormalRandom (double dMean, double dStdDevNorm, 
+			   double dStdDevLogNorm)
+{
+
+  double dmuz, dSLogNorm, dLambda, dz;
+
+  if (dMean < 0) { /* "True value must be >= 0 */
+    char str[10];
+    sprintf(str, "%5.2e", dMean);
+    ReportRunTimeError(NULL, RE_BADLOGNORMALMEAN | RE_FATAL,
+                       "", str, "GenLogNormalRandom");
+  }
+  else 
+    if (dStdDevLogNorm <= 0) {
+      char str[10];
+      sprintf(str, "%5.2e", dStdDevLogNorm);
+      ReportRunTimeError(NULL, RE_BADLOGNORMALSD | RE_FATAL,
+                         "", str, "GenLogNormalRandom");
+    }
+
+  /* Relative Standard Deviation of Lognormal */
+  dSLogNorm = sqrt(exp(pow(dStdDevLogNorm,2)) * 
+		   (exp(pow(dStdDevLogNorm,2)) - 1)); 
+  /* Transformation parameter */
+  dLambda = pow(dStdDevNorm/dSLogNorm,2);
+  /* Transformation of mean */
+  dmuz = log(dMean + sqrt(pow(dMean,2) + dLambda));
+  /* Random variate of transformed variable */
+  dz = NormalRandom(dmuz, dSLogNorm);
+
+  return (exp(dz) - dLambda * exp(-dz))/2;  /* return untransformed variable */
+
+} /* GenLogNormalRandom */
+
+
+/* ----------------------------------------------------------------------------
+   StudentTRandom
+
+   Returns a random variate from Student T distribution with dof
+   degrees of freedom, location dMean, and scale dStdDev.
+*/
+
+double StudentTRandom (double dof, double dMean, double dStdDev)
+{
+
+  double z, x;
+
+  if (dof <= 0) {
+    printf ("Error: StudentTRandom: dof <= 0\n");
+    exit (0);
+  }
+  z = NormalRandom(0,1);
+  x = Chi2Random(dof);
+
+  return (dMean + dStdDev*z*sqrt(dof/x));
+
+} /* StudentTRandom */
+
+
 /* ----------------------------------------------------------------------------
    TruncNormalRandom
 
