@@ -4,7 +4,7 @@
    modifications by Don Robert Maszle
    8 January 1992
 
-   Copyright (c) 1992-2004.  Don Maszle, Frederic Bois.  All rights reserved.
+   Copyright (c) 1992-2004.  Don Maszle, Frederic Bois.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -18,7 +18,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+   Foundation, Inc., 51 Franklin Street, 5th Floor, Boston, MA 02110-1301, USA.
 
    -- Revisions -----
      Logfile:  %F%
@@ -32,6 +32,10 @@
    documentation.
 
    Gives prototypes for random functions.
+
+   2005-09-06: Weihsueh A. Chiu (WAC) -- added generalized lognormal and
+   student T routines header (GenLogNormalRandom and StudentTRandom).
+
 */
 
 #ifndef _RANDOM_H_
@@ -75,6 +79,9 @@ double TruncInvGGammaRandom (double alpha, double beta, double a, double b);
 double GammaRandom (double alpha);
 double GGammaRandom (double alpha, double beta);
 double LogNormalRandom (double dMean, double dStdDev);
+double GenLogNormalRandom (double dMean, double dStdDevNorm, 
+			   double dStdDevLogNorm);
+double StudentTRandom (double dof, double dMean, double dStdDev);
 double LogUniformRandom (double a, double b);
 double NormalRandom (double dMean, double dStdDev);
 double PiecewiseRandom (double min, double a, double b, double max);
