@@ -1,6 +1,6 @@
 /* sim.c
 
-   Copyright (c) 1993-2004.  Don Maszle, Frederic Bois.  All rights reserved.
+   Copyright (c) 1993-2004.  Don Maszle, Frederic Bois.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+   Foundation, Inc., 51 Franklin Street, 5th Floor, Boston, MA 02110-1301, USA.
 
    -- Revisions -----
      Logfile:  %F%
@@ -235,6 +235,13 @@ int DoOneExperiment (PEXPERIMENT pexp)
 
       /* the upper limit of integration dTup should be either dTout
          or dTtrans, whichever is smaller */
+      /* F. Bois, 08 April 2007: before that, if the difference between dTout 
+         and dTtrans is too small make dTtrans = dTout to avoid problems with
+         the integration */
+      if (fabs(dTout - dTtrans) < DBL_EPSILON * 2.0 * 
+                                  mymax(fabs(dTout), fabs(dTtrans)))
+        dTtrans = dTout;
+
       dTup = (dTout < dTtrans) ? dTout : dTtrans;
 
       if (pis->iAlgo == IAL_LSODES) { /* Lsodes algorithm */
@@ -688,7 +695,7 @@ void GetOutputFlagOption (PANALYSIS panal, char *optarg)
 
 
 /* ----------------------------------------------------------------------------
-   GetFilenames
+   GetCmdLineArgs
 
    retrieves options and filenames from the command line arguments passed to
    the program.
@@ -758,7 +765,7 @@ void GetCmdLineArgs (int cArg, char *const *rgszArg, PSTR *pszFileIn,
 
   } /* while */
 
-  switch (cArg - optind) { /* Remaining args are  filenames */
+  switch (cArg - optind) { /* Remaining args are filenames */
     case 2: /* Output and input file specificed */
       *pszFileOut = rgszArg[optind + 1];
 
