@@ -2,7 +2,7 @@
 
    originally written by Don Maszle
 
-   Copyright (c) 1993-2004.  Don Maszle, Frederic Bois.  All rights reserved.
+   Copyright (c) 1993-2004.  Don Maszle, Frederic Bois.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -16,7 +16,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+   Foundation, Inc., 51 Franklin Street, 5th Floor, Boston, MA 02110-1301, USA.
 
    -- Revisions -----
      Logfile:  %F%
@@ -29,6 +29,7 @@
    Header file for simulation
 
    Modified the obsolete "Options Flags"
+
 */
 
 #ifndef _SIM_H_
@@ -114,6 +115,11 @@
 #define KM_BINOMIALBETA    228
 #define KM_HALFNORMAL      229
 #define KM_TRUNCINVGGAMMA  230
+/* WAC -- added Generalized Lognormal and Student T -- 2005-09-06 */
+#define KM_GENLOGNORMAL    231    
+#define KM_STUDENTT        232
+
+
 
 #define KM_PREDICTION      300
 
@@ -166,6 +172,9 @@
 #define MCV_BINOMIALBETA    18
 #define MCV_HALFNORMAL      19
 #define MCV_TRUNCINVGGAMMA  20
+/* WAC -- added Generalized Lognormal and Student T -- 2005-09-06 */
+#define MCV_GENLOGNORMAL    21
+#define MCV_STUDENTT        22
 
 /* Integration Method types */
 
