@@ -3,7 +3,7 @@
    written by Don Maszle
    16 October 1991
 
-   Copyright (c) 1991-2004.  Don Maszle, Frederic Bois.  All rights reserved.
+   Copyright (c) 1991-2004.  Don Maszle, Frederic Bois.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+   Foundation, Inc., 51 Franklin Street, 5th Floor, Boston, MA 02110-1301, USA.
 
    -- Revisions -----
      Logfile:  %F%
@@ -121,7 +121,9 @@ KM vrgkmKeywordMap[] = { /* Global Keyword - code map */
   {"TruncNormal_v",   KM_TRUNCNORMALV,    CN_FUNCARG},
   {"TruncLogNormal_v",KM_TRUNCLOGNORMALV, CN_FUNCARG},
   {"BinomialBeta",    KM_BINOMIALBETA,    CN_FUNCARG},
-  
+  {"GenLogNormal",    KM_GENLOGNORMAL,    CN_FUNCARG}, 
+  {"StudentT",        KM_STUDENTT,        CN_FUNCARG},
+
   {"Prediction",    KM_PREDICTION,        CN_FUNCARG},
 
   {"Euler",         KM_EULER,             CN_FUNCARG},
@@ -264,6 +266,8 @@ int McvFromLex (PSTR szLex)
              : ikwcode == KM_TRUNCNORMALV   ? MCV_TRUNCNORMALV
              : ikwcode == KM_TRUNCLOGNORMALV? MCV_TRUNCLOGNORMALV
              : ikwcode == KM_BINOMIALBETA   ? MCV_BINOMIALBETA
+             : ikwcode == KM_GENLOGNORMAL   ? MCV_GENLOGNORMAL 
+             : ikwcode == KM_STUDENTT       ? MCV_STUDENTT 
              : (-1));
 
   return iReturn;
@@ -1335,7 +1339,9 @@ int GetDistribSpec (PINPUTBUF pibIn, PANALYSIS panal, PSTR szLex)
       break;
 
     /* ----------------------------------------------------------------------*/
-    case MCV_BINOMIALBETA: /* 3 parameter: mean, alpha, beta */
+    case MCV_BINOMIALBETA: /* 3 parameter: mean, alpha,    beta */
+    case MCV_GENLOGNORMAL: /* 3 parameter: mean, sdnorm,   sdlognorm */
+    case MCV_STUDENTT:     /* 3 parameter: dof,  location, scale */
 
       if ((iErr = GetDistribParam (pibIn, szLex, plist, 0, pMCVar)))
         goto Done_GetMCVary;
