@@ -1,6 +1,6 @@
 /* simmonte.c
 
-   Copyright (c) 1993-2004.  Don Maszle, Frederic Bois.  All rights reserved.
+   Copyright (c) 1993-2004.  Don Maszle, Frederic Bois.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+   Foundation, Inc., 51 Franklin Street, 5th Floor, Boston, MA 02110-1301, USA.
 
    -- Revisions -----
      Logfile:  %F%
@@ -25,6 +25,7 @@
    -- SCCS  ---------
 
    Handles functions related to Monte Carlo analysis.
+
 */
 
 #include <assert.h>
@@ -197,6 +198,16 @@ int CalculateOneMCParm (PMCVAR pMCVar)
       pMCVar->dVal = BinomialBetaRandom (dParm1, dParm2, dMin);
       break;
 
+    /* WAC -- added Generalized Lognormal and Student T -- 2005-09-06 */
+
+    case MCV_GENLOGNORMAL: /* dMin is in fact stdevlognorm */
+      pMCVar->dVal = GenLogNormalRandom (dParm1, dParm2, dMin);
+      break;
+
+    case MCV_STUDENTT: /* dMin is in fact the scale parameter */
+      pMCVar->dVal = StudentTRandom (dParm1, dParm2, dMin);
+      break;
+
   } /* switch */
 
   return 0;
